@@ -29,6 +29,7 @@ sub new    #_HTTP_Response
 		'page'       => undef,
 		'version'    => undef,
 		'comment'    => undef,
+		'tempdir'    => undef,
 	};
 	for my $key ( keys %patent_parameters_passed ) {
 		if ( exists $self->{$key} ) {
@@ -199,6 +200,14 @@ Access parameters, including content, programmatically (politely).
 
 a classic
 
+=head2 message
+
+the message
+
+=head2 is_success
+
+not failed
+
 =cut
 
 =head2 content
